@@ -6,8 +6,7 @@ module Innate
       def self.call(action, string)
         erb = View.compile(string){|str| ::ERB.new(str, nil, '%<>') }
         erb.filename = (action.view || action.method).to_s
-        html = erb.result(action.binding)
-        return html, Response.mime_type
+        erb.result(action.binding)
       end
     end
   end
